@@ -36,6 +36,11 @@ class GetAggregateResourceComplianceByConfigRuleRequest(RpcRequest):
 
 	def set_ConfigRuleId(self, ConfigRuleId):  # String
 		self.add_query_param('ConfigRuleId', ConfigRuleId)
+	def get_ResourceOwnerId(self): # Long
+		return self.get_query_params().get('ResourceOwnerId')
+
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
 	def get_AggregatorId(self): # String
 		return self.get_query_params().get('AggregatorId')
 
